@@ -9,7 +9,7 @@
 --
 --	editor.lua	-	Editor configuration and functions.
 --
---	(c) Copyright 2002-2007 by Lutz Sammer, Francois Beerten and Jimmy Salmon
+--	(c) Copyright 2002-2008 by Lutz Sammer, Francois Beerten and Jimmy Salmon
 --
 --      This program is free software; you can redistribute it and/or modify
 --      it under the terms of the GNU General Public License as published by
@@ -31,9 +31,16 @@ Load("scripts/uilayout.lua")
 
 HandleCommandKey = HandleEditorIngameCommandKey
 
+DefineIcon({
+  Name = "icon-editor-patch",
+  Size = {46, 38},
+  Frame = 0,
+  File = "graphics/ui/editor_patch.png"})
+
 -- Set which icons to display
 SetEditorSelectIcon("icon-patrol")
 SetEditorUnitsIcon("icon-assault")
+SetEditorPatchIcon("icon-editor-patch")
 
 -- Start location unit
 DefineIcon({
@@ -47,7 +54,7 @@ DefineUnitType("unit-start-location", {
   Animations = "animations-building", Icon = "icon-start-location",
   Speed = 0, HitPoints = 0, DrawLevel = 0, TileSize = {1, 1},
   BoxSize = {31, 31}, SightRange = 0, BasicDamage = 0, PiercingDamage = 0,
-  Missile = "missile-none", Priority = 0, Type = "land",
+  Missile = "missile-none", Priority = 0, Type = "land", NumDirections = 1,
  })
 SetEditorStartUnit("unit-start-location")
 
@@ -63,7 +70,6 @@ local editor_types = {
   "unit-assault",
   "unit-bazoo",
   "unit-grenadier",
-  "unit-dorcoz",
   "unit-engineer",
   "unit-harvester",
   "unit-msilo",
@@ -75,6 +81,8 @@ local editor_types = {
   "unit-hosp",
   "unit-vfac",
   "unit-gturret",
+  "unit-biggunturret",
+  "unit-cannon",
   "unit-cam",
   "unit-radar",
   "unit-buggy",
@@ -84,6 +92,7 @@ local editor_types = {
   "unit-chopper",
   "unit-bomber",
   "unit-jet",
+  "unit-heli",
 
   "unit-tree",
   "unit-tree02",
