@@ -9,7 +9,7 @@
 --
 --      guichan.lua - The main UI lua script.
 --
---      (c) Copyright 2005-2008 by François Beerten
+--      (c) Copyright 2005-2010 by François Beerten
 --
 --      This program is free software; you can redistribute it and/or modify
 --      it under the terms of the GNU General Public License as published by
@@ -100,6 +100,59 @@ function AddMenuHelpers(menu)
     return self:addLabel(text, x, y, Fonts["large"], false)
   end
 
+  -- Arrange widgets in a grid, with automatic column widths and
+  -- padding.  Align the left sides of the widgets in each column.
+  -- This function moves the widgets only horizontally, leaving
+  -- the Y coordinates unchanged.
+  --
+  -- The grid parameter is a table of rows, each of which is a table
+  -- of widgets.  Each row should have the same number of widgets.
+  -- A rows must be a plain array without specific keys.
+  -- (Actually, because this function ignores the Y coordinates,
+  -- it might be more natural if the parameter were a table of columns;
+  -- but the current format is a bit easier for the caller to provide.)
+  function menu:adjustColumnWidths(grid)
+    local columnWidths = {}
+    local width
+    local spareWidth
+    local rowNumber
+    local row
+    local columnNumber
+    local maxGap = menu:getWidth() / 16
+    local gap
+    local x
+    -- Compute the width needed for each column.
+    for rowNumber,row in ipairs(grid) do
+      for columnNumber,widget in ipairs(row) do
+        width = widget:getWidth()
+        if columnWidths[columnNumber] == nil or columnWidths[columnNumber] < width then
+          columnWidths[columnNumber] = width
+        end
+      end
+    end
+    -- How much width will be left over from the columns?
+    spareWidth = menu:getWidth()
+    for k,v in ipairs(columnWidths) do
+      spareWidth = spareWidth - v
+    end
+    -- Keep the columns as far from the edges of the menu
+    -- as they are from each other.
+    gap = spareWidth / (#columnWidths + 1)
+    -- However, if the columns would get too far from each other,
+    -- then move them closer, and leave more space at the edges.
+    if gap > maxGap then
+      gap = maxGap
+    end
+    -- Move all the widgets to their final positions.
+    for rowNumber,row in ipairs(grid) do
+      x = (spareWidth - gap * (#columnWidths - 1)) / 2
+      for columnNumber,widget in ipairs(row) do
+        widget:setX(x)
+        x = x + columnWidths[columnNumber] + gap
+      end
+    end
+  end
+
   function menu:addButton(caption, x, y, callback, size)
     local b = ButtonWidget(caption)
     b:setActionCallback(callback)
@@ -319,18 +372,13 @@ Widget:setGlobalFont(Fonts["large"])
 
 -- Define the different menus ----------
 
-function RunSubMenu(s)
-  local menu
-  menu = BosMenu(_("Empty sub menu"))
-  menu:run()
-end
-
 function RunResultsMenu()
   local menu
   local background = "graphics/screens/menu.png"
   local sx = Video.Width / 20
   local sy = Video.Height / 20
   local result
+  local grid
 
   if GameResult == GameVictory then
     result = _("Victory !")
@@ -351,22 +399,30 @@ function RunResultsMenu()
   menu = BosMenu(_("Results"), background)
   menu:writeLargeText(result, sx*6, sy*5)
 
-  menu:writeText(_("Player"), sx*3, sy*7)
-  menu:writeText(_("Units"), sx*6, sy*7)
-  menu:writeText(_("Buildings"), sx*8, sy*7)
-  menu:writeText(_("Kills"), sx*10, sy*7)
-  menu:writeText(_("Razings"), sx*12, sy*7)
+  -- The X coordinates of these widgets will be set after all the
+  -- widgets have been created and their sizes are known.
+  grid = {{
+    menu:writeText(_("Player"), 0, sy*7),
+    menu:writeText(_("Units"), 0, sy*7),
+    menu:writeText(_("Buildings"), 0, sy*7),
+    menu:writeText(_("Kills"), 0, sy*7),
+    menu:writeText(_("Razings"), 0, sy*7)
+  }}
 
   for i=0,7 do
     if (Players[i].TotalUnits > 0) then
-      menu:writeText(i .. " ".. Players[i].Name, sx*3, sy*(8+i))
-      menu:writeText(Players[i].TotalUnits, sx*6, sy*(8+i))
-      menu:writeText(Players[i].TotalBuildings, sx*8, sy*(8+i))
-      menu:writeText(Players[i].TotalKills, sx*10, sy*(8+i))
-      menu:writeText(Players[i].TotalRazings, sx*12, sy*(8+i))     
+      table.insert(grid, {
+	menu:writeText(i .. " ".. Players[i].Name, 0, sy*(8+i)),
+	menu:writeText(Players[i].TotalUnits, 0, sy*(8+i)),
+	menu:writeText(Players[i].TotalBuildings, 0, sy*(8+i)),
+	menu:writeText(Players[i].TotalKills, 0, sy*(8+i)),
+	menu:writeText(Players[i].TotalRazings, 0, sy*(8+i))
+      })
     end
   end
 
+  menu:adjustColumnWidths(grid)
+
   menu:addButton(_("~!Continue"), Video.Width / 2 - 100, Video.Height - 100,
                  function() menu:stop() end)
 
@@ -441,8 +497,7 @@ function GameStarting()
   Cheater = false
 
   -- FIXME: get the version from somewhere else
-  UI.StatusLine:Set("Bos Wars V" .. "2.5.0" ..
-    ", (c) 1998-2008 by the Bos Wars and Stratagus Project.")
+  UI.StatusLine:Set("Bos Wars V2.6.0 (c) 1998-2010 by the Bos Wars Team.")
 end
 
 
@@ -470,10 +525,10 @@ function RunStartGameMenu(s)
 
   menu:writeLargeText(_("Map"), sx, sy*3)
   menu:writeText(_("File:"), sx, sy*3+30)
-  local maptext = menu:writeText(selectedmap, sx+50, sy*3+30)
+  local maptext = menu:writeText(selectedmap, sx+70, sy*3+30)
   maptext:setWidth(sx * 9 - 50 - 20)
   menu:writeText(_("Size:"), sx, sy*3+50)
-  local mapsize = menu:writeText("       ", sx+50, sy*3+50)
+  local mapsize = menu:writeText("       ", sx+70, sy*3+50)
   mapsize:setWidth(sx * 9 - 50 - 20)
   menu:writeText(_("Players:"), sx, sy*3+70)
   local players = menu:writeText("             ", sx+70, sy*3+70)
@@ -620,11 +675,14 @@ function RunEditorMenu(s)
 
   menu = BosMenu(_("Editor"))
 
-  menu:addButton(_("Create ~!New Map"), x, 260,
+  menu:addButton(_("Create ~!New Map"), x, 220,
     function() RunEditorNewMenu(); menu:stop() end)
-  menu:addButton(_("~!Load Map"), x, 300,
+  menu:addButton(_("~!Load Map"), x, 260,
     function() RunEditorLoadMenu(); menu:stop() end)
 
+  menu:addButton(_("~!Patch Editor"), x, 320,
+    function() RunPatchEditorMenu(); menu:stop() end)
+
   menu:addButton(_("~!Cancel"), x, Video.Height - 100,
     function() menu:stop() end)
 
@@ -641,9 +699,6 @@ function RunEditorNewMenu()
   menu = BosMenu(_("Editor"))
 
   function starteditorbutton(s)
-    -- FIXME: select tileset or image based map
-    LoadTileModels("scripts/tilesets/desert.lua")
-
     local n = tonumber(xsize:getText())
     if (n == nil) then n = 64 end
     Map.Info.MapWidth = n
@@ -692,7 +747,7 @@ function RunEditorLoadMenu()
 
   menu:writeLargeText(_("Map"), sx, sy*3)
   menu:writeText(_("File:"), sx, sy*3+30)
-  local maptext = menu:writeText(selectedmap .. "                       ", sx+50, sy*3+30)
+  local maptext = menu:writeText(selectedmap .. "                       ", sx+70, sy*3+30)
   menu:writeText(_("Players:"), sx, sy*3+50)
   local players = menu:writeText("             ", sx+70, sy*3+50)
   menu:writeText(_("Size:"), sx, sy*3+70)
@@ -739,6 +794,7 @@ Load("scripts/menus/options.lua")
 Load("scripts/menus/credits.lua")
 Load("scripts/menus/ingame/game.lua")
 Load("scripts/menus/ingame/editor.lua")
+Load("scripts/menus/patch.lua")
 Load("scripts/menus/campaigns.lua")
 
 function BuildMainMenu(menu)
