@@ -75,7 +75,7 @@ function RunEditorSaveMenu()
   end
   browser:setActionCallback(cb)
 
-  menu:addSmallButton(_("Save"), 16, 248,
+  menu:addSmallButton(_("~!Save"), 16, 248,
     -- FIXME: use a confirm menu if the file exists already
     function()
       local mapname = browser.path .. t:getText()
@@ -84,7 +84,7 @@ function RunEditorSaveMenu()
       menu:stop()
     end)
 
-  menu:addSmallButton(_("Cancel"), 16 + 12 + 106, 248,
+  menu:addSmallButton(_("~!Cancel"), 16 + 12 + 106, 248,
     function() menu:stop() end)
 
   menu:run(false)
@@ -233,3 +233,5 @@ function RunEditorPlayerPropertiesMenu()
   menu:run(false)
 end
 
+
+
