@@ -25,7 +25,6 @@
 --      along with this program; if not, write to the Free Software
 --      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 --
---	$Id: unit-jet.lua 8935 2007-06-24 20:18:51Z gruiick $
 
 DefineAnimations("animations-jet", {
     Still = {"frame 0", "wait 1", },
@@ -64,7 +63,6 @@ DefineUnitType("unit-jet", {
                   "offset", {5, 128}},
     Animations = "animations-jet",
     Icon = "icon-jet",
-    Flip = false,
     EnergyValue = 8000,
     MagmaValue = 3000,
     Speed = 60,
@@ -105,7 +103,7 @@ DefineAllow("unit-jet", AllowAll)
 
 DefineButton({
     Pos = 1, Level = 0, Icon = "icon-jet", Action = "train-unit",
-    Value = "unit-jet", Key = "j", Hint = "BUILD ~!JET FIGHTER",
+    Value = "unit-jet", Hint = "BUILD ~!JET FIGHTER",
     ForUnit = {"unit-aircraftfactory"}})
 
 DefineCommonButtons({"unit-jet"})
